==> currents-api-types-0.0.35.tgz: package/constants.ts <==
const MIXSPACE_CRUD_IDS = [
  'createMixspace',
  'updateMixspace',
  'fetchMixspaces',
  'fetchMixspace',
  'deleteMixspace',
] as const;
const BLOG_CRUD_IDS = ['createBlog', 'updateBlog', 'fetchBlogs', 'fetchBlog', 'deleteBlog'] as const;
const COLLECTIVE_CRUD_IDS = [
  'createCollective',
  'updateCollective',
  'fetchCollectives',
  'fetchCollective',
  'deleteCollective',
] as const;
const PAYIN_METHOD_CRUD_IDS = ['upsertPayinMethod', 'fetchPayinMethods', 'deletePayinMethod'] as const;
// const PAYOUT_METHOD_CRUD_IDS = ['upsertPayoutMethod', 'fetchPayoutMethods', 'deletePayoutMethod'] as const;
const PAYOUT_METHOD_CRUD_IDS = ['fetchPayoutMethods'] as const;
const PAYOUT_METHID_SPECIAL_IDS = ['payoutMethodStripeAuthorize', 'payoutMethodStripeToken'] as const;
const AUTH_USERS_CRUD_IDS = ['fetchAuthUsers', 'fetchAuthUser'] as const;
const SUBSCRIPTION_CRUD_IDS = [
  'fetchSubscriptions',
  'createSubscription',
  'updateSubscription',
  'deleteSubscription',
] as const;
const TIP_CRUD_IDS = ['fetchTips', 'createTip'] as const;
const PAYOUT_CRUD_IDS = ['runPayout'] as const;

export const ROUTE_IDS = [
  'localSignup',
  'signout',
  'localSignin',
  'googleAuthInit',
  'resetPassword',
  ...BLOG_CRUD_IDS,
  ...COLLECTIVE_CRUD_IDS,
  ...AUTH_USERS_CRUD_IDS,
  ...MIXSPACE_CRUD_IDS,
  'payinRoute',
  ...PAYIN_METHOD_CRUD_IDS,
  ...PAYOUT_METHOD_CRUD_IDS,
  ...PAYOUT_METHID_SPECIAL_IDS,
  ...SUBSCRIPTION_CRUD_IDS,
  ...TIP_CRUD_IDS,
  'channelAutocomplete',
  ...PAYOUT_CRUD_IDS,
] as const;
export const FIRESTORE_API_GET_LIMIT = 1000;
// dupe with graph inner constant; checked for validity
export const MAX_HISTORICAL_DATE_MS = 8640000000000000; // not max integer

==> currents-api-types-0.0.36.tgz: package/constants.ts <==
const MIXSPACE_CRUD_IDS = [
  'createMixspace',
  'updateMixspace',
  'fetchMixspaces',
  'fetchMixspace',
  'deleteMixspace',
] as const;
const BLOG_CRUD_IDS = ['createBlog', 'updateBlog', 'fetchBlogs', 'fetchBlog', 'deleteBlog'] as const;
const COLLECTIVE_CRUD_IDS = [
  'createCollective',
  'updateCollective',
  'fetchCollectives',
  'fetchCollective',
  'deleteCollective',
] as const;
const PAYIN_METHOD_CRUD_IDS = ['upsertPayinMethod', 'fetchPayinMethods', 'deletePayinMethod'] as const;
// const PAYOUT_METHOD_CRUD_IDS = ['upsertPayoutMethod', 'fetchPayoutMethods', 'deletePayoutMethod'] as const;
const PAYOUT_METHOD_CRUD_IDS = ['fetchPayoutMethods'] as const;
const PAYOUT_METHID_SPECIAL_IDS = ['payoutMethodStripeAuthorize', 'payoutMethodStripeToken'] as const;
const AUTH_USERS_CRUD_IDS = ['fetchAuthUsers', 'fetchAuthUser'] as const;
const SUBSCRIPTION_CRUD_IDS = [
  'fetchSubscriptions',
  'createSubscription',
  'updateSubscription',
  'deleteSubscription',
] as const;
const TIP_CRUD_IDS = ['fetchTips', 'createTip'] as const;
const PAYOUT_CRUD_IDS = ['runPayout', 'retryPayout', 'payoutBatchStatus', 'listPayoutQuery'] as const;

export const ROUTE_IDS = [
  'localSignup',
  'signout',
  'localSignin',
  'googleAuthInit',
  'resetPassword',
  ...BLOG_CRUD_IDS,
  ...COLLECTIVE_CRUD_IDS,
  ...AUTH_USERS_CRUD_IDS,
  ...MIXSPACE_CRUD_IDS,
  'payinRoute',
  ...PAYIN_METHOD_CRUD_IDS,
  ...PAYOUT_METHOD_CRUD_IDS,
  ...PAYOUT_METHID_SPECIAL_IDS,
  ...SUBSCRIPTION_CRUD_IDS,
  ...TIP_CRUD_IDS,
  'channelAutocomplete',
  ...PAYOUT_CRUD_IDS,
] as const;
export const FIRESTORE_API_GET_LIMIT = 1000;
// dupe with graph inner constant; checked for validity
export const MAX_HISTORICAL_DATE_MS = 8640000000000000; // not max integer
